# Hackability (puddl, vision)
Expected skill-level of contributors: script-kiddie.

When in doubt which implementation to choose,
prefer the one that is more hackable.
Scripts are easily readable from top to bottom.
Scripts can be easily composed using UNIX tools.
The file system is your friend.
Globbing is great to batch things.


# Why Rhyming?

- 4 elements / rap
- verdichtung --> reim --> merken
- puddl-rhymes


## Finding a Rhyme Machine (German)
- https://www.d-rhyme.de/
  - good quality rhymes
  - authorization required --> Assholes!
- https://reimmaschine.de/?wort=rational
  - ads
- https://www.was-reimt-sich-auf.de/rational.html
  - clean URL
  - good quality rhymes
  - no BS
  - Thanks guys! :)


# Vim Tricks
Set up vim to treat `-` like any other character in tab completion:
```
set iskeyword+=-
```

Before:
```
bin/p<C-x><C-f>
-->
bin/puddl
```

After:
```
bin/p<C-x><C-f>
-->
bin/puddl-audio-remove-silence
bin/puddl-curl
...
```
